### Começar

PDFMathTranslate é uma ferramenta poderosa de tradução de PDF. Você pode instalar e começar a usar esta ferramenta de várias maneiras.

---

### Instalação

1. [**Windows EXE**](./INSTALLATION_winexe.md) <small>Recomendado para Windows</small>
2. [**Docker**](./INSTALLATION_docker.md) <small>Recomendado para Linux</small>
3. [**uv** (um gerenciador de pacotes Python)](./INSTALLATION_uv.md) <small>Recomendado para macOS</small>

---

### Uso

1. [Usando **WebUI**](./USAGE_webui.md)
2. [Usando **Plugin do Zotero**](https://github.com/guaguastandup/zotero-pdf2zh) (Programa de terceiros)
3. [Usando **Linha de comando**](./USAGE_commandline.md)

<div align="right"> 
<h6><small>Parte do conteúdo desta página foi traduzida pelo GPT e pode conter erros.</small></h6>